bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.get_mask
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.get_mask